@@ -361,14 +361,6 @@ def read_file_record(gen):
 		else:
 			sys.exit("Error: snap filelists not coherent.")
 
-	print("=========")
-	print(f"i={i}")
-	print(f"p={p}")
-	print(f"t={t}")
-	print(f"d={d}")
-	print(f"s={s}")
-	print(f"perms={perms}")
-
 	d = d.split(".")[0]	# truncate date to seconds
 	if t=="d": d=s="0"	# ignore dates/size for dirs (set to zero)
 	if ignoreperms: perms = ""
